@@ -4,4 +4,4 @@ from pydantic import BaseModel
 class BaseEventMessage(BaseModel):
     event: str
     time: float
-    strategy_id: float
\ No newline at end of file
+    strategy_id: str
\ No newline at end of file
