@@ -1,3 +1,6 @@
+from typing import Dict
+
+from odin_messages.balance import CoinBalance
 from odin_messages.base import BaseEventMessage
 
 class NewOpenOrderMessage(BaseEventMessage):
@@ -37,3 +40,7 @@ class WalletBalanceUpdate(BaseEventMessage):
     balance: float
     used_balance: float
 
+class FirstBalance(BaseEventMessage):
+    exchange: str
+    coins: Dict[str, CoinBalance]
+
